# This pipeline was automatically generated

## Setup

```sh
pip install -r requirements.txt
```

## Usage

List tasks:

```sh
ploomber status
```

Execute:

```sh
ploomber build
```

Plot:

```sh
ploomber plot
```

*Note:* plotting requires `pygraphviz` for instructions, [see this.](https://docs.ploomber.io/en/latest/user-guide/faq_index.html#plotting-a-pipeline)

## Resources

* [Ploomber documentation](https://docs.ploomber.io)